// %PARAMETERS = "12F675"

#include <pic.h>

//#define	_READ_OSCCAL_DATA()	(*(unsigned char(*)())0x3FF)()

__CONFIG(INTIO & BOREN & UNPROTECT & PWRTEN & WDTDIS & MCLRDIS);

/*******************************************************
*
*            +---+   +---+
*       Vdd -+1  +---+  8+- Vss
*     GPIO5 -+2   12F   7+- GPIO0
*     GPIO4 -+3   675   6+- GPIO1
*     GPIO3 -+4         5+- GPIO2
*            +-----------+
*       
*	Minuterie d'Arrosage Simple
*       Cette minuterie est destine  commander une lectrovanne d'arrosage
*       automatique 30 minutes par jour. Avec des goutteurs de 2l/h cela fait
*       1 l par jour par goutteur. 50 mtre de tuyau avec un goutteur tous les
*       30 cm cela fait environ 165 litre/jour soit 1m3 d'eau tous les 6 jours.
*
*       Auteur: Philippe RICHARD (pseudo philrich123)
*       Web: http://philrich123.free.fr
*
*       GPIO4,5 relis ensemble en Sortie pour obtenir
*       un courant de 50mA maxi (Relais utilis = 30mA)
*
*	p7 : GPIO0 = N.C.
*	p6 : GPIO1 = N.C.
*	p5 : GPIO2 = Entre marche force (1: marche continue, pulse: 30 mn)
*	p4 : GPIO3 = Non utilis : Connecter au +5V ou  la masse
*	p3 : GPIO4 = Commande relais
*	p2 : GPIO5 = Commande relais
*
*       Prvoir une rsistance de tirage de 10k  la masse pour GPIO2
*
***********************************************************/

int temps;    // Temps de fonctionnement programm en minutes
int demisec;  // Nombre de 1/2 secondes (120 par minute)

void interrupt isr_timer1(void);

void interrupt isr_timer1(void)
{
  demisec++;
  if (demisec>=120)  // 120 demis secondes cela fait 1 minute
  {
    if (temps>0) temps--;
    demisec=0;
  }
  TMR1ON=0;
  //TMR1H=0xFB; // Pour debug 2*60Hz au lieu de 2Hz
  //TMR1L=0xEE; // => Les heures deviennent des minutes
  TMR1H=0x0B; // TMR1 = 0x0BDC = 3036 = 65536-62500
  TMR1L=0xDC; // (1MHz / 8 ) / 62500 = 2 Hz
  TMR1ON=1;
  TMR1IF=0;
}

/* programme principal */

main (void)
{
  OSCCAL=_READ_OSCCAL_DATA();
  CMCON=7;                     // Pas d'utilisation du convertisseur A/D
  ANSEL=0;                     //        et du comparateur analogique
  GPIO=0;
  TRISIO=0b00001100;           // GPIO 2,3 entres   -   GPIO 0,1,4,5 sorties

  GPIO=GPIO | 0b00110000;
  temps=0;
  demisec=0;

  // config timer 1
  TMR1ON=1;
  T1CKPS1=T1CKPS0=1; // Prescaler 1:8
  T1OSCEN=0;         // pas d'oscillateur low power
  T1SYNC=0;
  TMR1CS=0;          // oscillateur interne Fosc/4
  TMR1ON=1;

  // config interruptions TIMER1
  TMR1IE=1;
  PEIE=1;
  GIE=1;

  // La commande marche se fait entre 23h30 et 23h59
  // Initialisation du compteur de temps  23h00
  temps=22*60-1; // 24 heures (Arrt pour 23 Heures sur Reset)

  while (1)
  {
    // Commande de marche force
    if (GPIO2==1) temps=24*60-1;

    // Gestion de la commande du relais 30 minutes par 24 Heures
    if (temps>22*60) GPIO=GPIO | 0b00110000;
    else GPIO=GPIO & 0b11001111;

    if (temps==0) temps=24*60-1;
  }
}

